# sw4iot-etcd

[![Build Status](https://img.shields.io/travis/sw4iot/sw4iot-etcd.svg)](https://travis-ci.org/sw4iot/sw4iot-etcd)
[![PyPI](https://img.shields.io/pypi/v/sw4iot-etcd.svg)](https://pypi.org/project/sw4iot-etcd/)
[![Updates](https://pyup.io/repos/github/sw4iot/sw4iot-etcd/shield.svg)](https://pyup.io/repos/github/sw4iot/sw4iot-etcd/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sw4iot-etcd.svg)
[![Hex.pm](https://img.shields.io/hexpm/l/plug.svg)](https://www.apache.org/licenses/LICENSE-2.0)
